package KiokuDB::TypeMap::Default::Storable;
BEGIN {
  $KiokuDB::TypeMap::Default::Storable::AUTHORITY = 'cpan:NUFFIN';
}
{
  $KiokuDB::TypeMap::Default::Storable::VERSION = '0.56';
}
use Moose;

use namespace::clean -except => 'meta';

extends qw(KiokuDB::TypeMap);

with qw(KiokuDB::TypeMap::Default::Passthrough);

__PACKAGE__->meta->make_immutable;

__PACKAGE__

__END__

=pod

=head1 NAME

KiokuDB::TypeMap::Default::Storable

=head1 VERSION

version 0.56

=head1 AUTHOR

Yuval Kogman <nothingmuch@woobling.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Yuval Kogman, Infinity Interactive.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
